@@ -2,29 +2,27 @@
     Copyright (c) 2006 Jacob R Rideout <kde@jacobrideout.net>
     Copyright (c) 2009 Jakub Stachowski <qbast@go2.pl>
     Copyright (c) 2013 Martin Sandsmark <martin.sandsmark@kde.org>
- 
+
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
     License as published by the Free Software Foundation; either
     version 2 of the License, or (at your option) any later version.
- 
+
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Library General Public License for more details.
- 
+
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QStandardPaths>
-#include <QtCore/QTime>
-#include <QtCore/QDataStream>
+#include <QCoreApplication>
+#include <QFile>
+#include <QStandardPaths>
+#include <QDataStream>
 #include <QLocale>
 
 #include "guesslanguage.h"
@@ -35,17 +33,17 @@
 #include "spellerplugin_p.h"
 
 /*
-All language tags should be valid according to IETF BCP 47, as codefied in RFC 4646.
+All language tags should be valid according to IETF BCP 47, as codified in RFC 4646.
 ISO 639-1 codes should be used for the language part except for cases where there
 exists no code, then 639-3 codes should be used. Country codes should only be used
-in special cases. Scripts can be differentiated by IANA subtags, availble here:
+in special cases. Scripts can be differentiated by IANA subtags, available here:
 http://www.iana.org/assignments/language-subtag-registry
-The script tags corresond to ISO 15924
+The script tags correspond to ISO 15924
 
 An overview of the best practices concerning language tagging is available here:
 http://www.w3.org/International/articles/language-tags/Overview.en.php
 
-lang tags should use underscores (_) rather than hypens (-) to sepereate subsections. 
+lang tags should use underscores (_) rather than hyphens (-) to separate subsections.
 
 EXCEPTIONS:
 For cases of known differences from the above tagging scheme and major
@@ -55,15 +53,9 @@ shall be used. All exception shall be noted here:
 BCP        SPELLCHECK
 az-Latn    az
 
-
 */
 
-namespace Sonnet
-{
-
-// Amount of trigrams in each file
-static const int MAXGRAMS = 300;
-
+namespace Sonnet {
 class GuessLanguagePrivate
 {
 public:
@@ -71,13 +63,13 @@ public:
     //            language       trigram  score
     static QHash< QString, QHash<QString, int> > s_knownModels;
 
-    void loadModels( );
-    QList< QChar::Script > findRuns(const QString& text);
-    QList<QString> createOrderedModel(const QString& content);
-    int distance( const QList<QString>& model, const QHash<QString,int>& knownModel );
-    QStringList guessFromTrigrams(const QString & sample, const QStringList& langs);
-    QStringList identify(const QString& sample, const QList< QChar::Script >& scripts);
-    QString guessFromDictionaries(const QString& sentence, const QStringList& candidates);
+    void loadModels();
+    QList< QChar::Script > findRuns(const QString &text);
+    QList<QString> createOrderedModel(const QString &content);
+    int distance(const QList<QString> &model, const QHash<QString, int> &knownModel);
+    QStringList guessFromTrigrams(const QString &sample, const QStringList &langs);
+    QStringList identify(const QString &sample, const QList< QChar::Script > &scripts);
+    QString guessFromDictionaries(const QString &sentence, const QStringList &candidates);
 
     static QSet<QString> s_knownDictionaries;
     static QMultiHash<QChar::Script, QString> s_scriptLanguages;
@@ -88,7 +80,7 @@ public:
     double m_minConfidence;
 };
 
-QHash< QString, QHash<QString,int> > GuessLanguagePrivate::s_knownModels;
+QHash< QString, QHash<QString, int> > GuessLanguagePrivate::s_knownModels;
 QSet<QString> GuessLanguagePrivate::s_knownDictionaries;
 QMultiHash<QChar::Script, QString> GuessLanguagePrivate::s_scriptLanguages;
 QMap<QString, QString> GuessLanguagePrivate::s_dictionaryNameMap;
@@ -96,21 +88,26 @@ QMap<QString, QString> GuessLanguagePrivate::s_dictionaryNameMap;
 QStringList getNames(QLocale::Script script)
 {
     QStringList locales;
-    for (const QLocale &locale : QLocale::matchingLocales(QLocale::AnyLanguage, script, QLocale::AnyCountry)) {
+    const auto matchingLocales = QLocale::matchingLocales(QLocale::AnyLanguage, script, QLocale::AnyCountry);
+    locales.reserve(matchingLocales.size());
+    for (const QLocale &locale : matchingLocales) {
         locales << locale.name();
     }
     return locales;
 }
 
 GuessLanguagePrivate::GuessLanguagePrivate()
-        : MIN_LENGTH(5), m_maxItems(1), m_minConfidence(0)
+    : MIN_LENGTH(5)
+    , m_maxItems(1)
+    , m_minConfidence(0)
 {
-    if (!s_scriptLanguages.isEmpty())
+    if (!s_scriptLanguages.isEmpty()) {
         return;
+    }
 
     s_knownDictionaries = Loader::openLoader()->languages().toSet();
     QSet<QString> dictionaryLanguages;
-    for (QString dictName : s_knownDictionaries) {
+    for (const QString &dictName : qAsConst(s_knownDictionaries)) {
         QString languageName = QLocale(dictName).name();
         if (languageName.isEmpty()) {
             qCWarning(SONNET_LOG_CORE) << "Unable to parse name for dictionary" << dictName;
@@ -120,10 +117,10 @@ GuessLanguagePrivate::GuessLanguagePrivate()
     }
 
     QSet<QString> allLanguages;
-    for (int i=0; i<int(QChar::ScriptCount); i++) {
-        QChar::Script script = (QChar::Script)i;
+    for (int i = 0; i < int(QChar::ScriptCount); i++) {
+        QChar::Script script = static_cast<QChar::Script>(i);
         QStringList names;
-        switch(script) {
+        switch (script) {
         case QChar::Script_Latin:
             names = getNames(QLocale::LatinScript);
             break;
@@ -489,7 +486,6 @@ GuessLanguagePrivate::GuessLanguagePrivate()
         case QChar::Script_WarangCiti:
             names = getNames(QLocale::VarangKshitiScript);
             break;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
         case QChar::Script_Ahom:
             names = getNames(QLocale::AhomScript);
             break;
@@ -505,14 +501,11 @@ GuessLanguagePrivate::GuessLanguagePrivate()
         case QChar::Script_OldHungarian:
             names = getNames(QLocale::OldHungarianScript);
             break;
-#endif
         case QChar::Script_Unknown:
         case QChar::Script_Inherited:
         case QChar::Script_Common:
         case QChar::Script_OldTurkic:
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
         case QChar::Script_SignWriting:
-#endif
             break;
         default:
             qCDebug(SONNET_LOG_CORE) << "Unhandled script" << script;
@@ -522,7 +515,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
 
         { // Remove unknown languages
             QStringList pruned;
-            for (const QString &name : names) {
+            for (const QString &name : qAsConst(names)) {
                 if (!dictionaryLanguages.contains(name)) {
                     continue;
                 }
@@ -535,7 +528,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
             continue;
         }
 
-        for (const QString &name : names) {
+        for (const QString &name : qAsConst(names)) {
             s_scriptLanguages.insert(script, name);
         }
     }
@@ -552,14 +545,15 @@ GuessLanguagePrivate::GuessLanguagePrivate()
             }
             s_dictionaryNameMap[languageName] = dictName;
             if (!s_scriptLanguages.values().contains(languageName)) {
-                qCWarning(SONNET_LOG_CORE) << "Unable to handle language from dictionary" << dictName << languageName;
+                qCWarning(SONNET_LOG_CORE) << "Unable to handle language from dictionary"
+                                           << dictName << languageName;
             }
         }
     }
 }
 
-GuessLanguage::GuessLanguage() :
-        d(new GuessLanguagePrivate)
+GuessLanguage::GuessLanguage()
+    : d(new GuessLanguagePrivate)
 {
 }
 
@@ -568,10 +562,11 @@ GuessLanguage::~GuessLanguage()
     delete d;
 }
 
-QString GuessLanguage::identify(const QString& text, const QStringList& suggestionsListIn) const
+QString GuessLanguage::identify(const QString &text, const QStringList &suggestionsListIn) const
 {
-    if (text.isEmpty())
+    if (text.isEmpty()) {
         return QString();
+    }
 
     // Filter for available dictionaries
     QStringList suggestionsList;
@@ -589,7 +584,7 @@ QString GuessLanguage::identify(const QString& text, const QStringList& suggesti
     QStringList candidateLanguages = d->identify(text, d->findRuns(text));
 
     // Hack for some bad dictionary names
-    for (int i=0; i<candidateLanguages.count(); i++) {
+    for (int i = 0; i < candidateLanguages.count(); i++) {
         if (d->s_dictionaryNameMap.contains(candidateLanguages[i])) {
             candidateLanguages[i] = d->s_dictionaryNameMap.value(candidateLanguages[i]);
         }
@@ -629,16 +624,14 @@ void GuessLanguage::setLimits(int maxItems, double minConfidence)
 
 void GuessLanguagePrivate::loadModels()
 {
-    QString triMapFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/sonnet/trigrams.map"));
-
-    if (triMapFile.isEmpty()) {
-        triMapFile = QStringLiteral("%1/../share/kf5/sonnet/trigrams.map").arg(QCoreApplication::applicationDirPath());
-    }
+    // use trigrams from resource file, easy to deploy on all platforms
+    const QString triMapFile = QStringLiteral(":/org.kde.sonnet/trigrams.map");
     qCDebug(SONNET_LOG_CORE) << "Loading trigrams from" << triMapFile;
 
     QFile sin(triMapFile);
     if (!sin.open(QIODevice::ReadOnly)) {
-        qCWarning(SONNET_LOG_CORE) << "Sonnet: Unable to load trigram models from file" << triMapFile;
+        qCWarning(SONNET_LOG_CORE) << "Sonnet: Unable to load trigram models from file"
+                                   << triMapFile;
         return;
     }
 
@@ -647,11 +640,13 @@ void GuessLanguagePrivate::loadModels()
 
     // Sanity check
     QSet<QString> availableLanguages;
-    QHashIterator<QString, QHash<QString, int>> iterator(s_knownModels);
+    QHashIterator<QString, QHash<QString, int> > iterator(s_knownModels);
     while (iterator.hasNext()) {
         iterator.next();
         if (iterator.value().count() < MAXGRAMS) {
-            qCWarning(SONNET_LOG_CORE) << iterator.key() << "is has only" << iterator.value().count() << "trigrams, expected" << MAXGRAMS;
+            qCWarning(SONNET_LOG_CORE) << iterator.key() << "is has only"
+                                       << iterator.value().count() << "trigrams, expected"
+                                       << MAXGRAMS;
         }
         availableLanguages.insert(iterator.key());
     }
@@ -662,14 +657,14 @@ void GuessLanguagePrivate::loadModels()
     }
 }
 
-QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString & text)
+QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString &text)
 {
     QChar::Script script = QChar::Script_Unknown;
     QHash<QChar::Script, int> scriptCounts;
 
     int totalCount = 0;
 
-    foreach (const QChar c, text) {
+    for (const QChar c : text) {
         script = c.script();
 
         if (script == QChar::Script_Common || script == QChar::Script_Inherited) {
@@ -686,13 +681,15 @@ QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString & text)
 
     QList<QChar::Script> relevantScripts;
 
-    if (totalCount == 0) return relevantScripts;
+    if (totalCount == 0) {
+        return relevantScripts;
+    }
 
-    foreach(const QChar::Script &script, scriptCounts.keys()) {
+    for (const QChar::Script &script : scriptCounts.keys()) {
         // return run types that used for 40% or more of the string
         if (scriptCounts[script] * 100 / totalCount >= 40) {
             relevantScripts << script;
-        // always return basic latin if found more than 15%.
+            // always return basic latin if found more than 15%.
         } else if (script == QChar::Script_Latin && scriptCounts[script] * 100 / totalCount >= 15) {
             relevantScripts << script;
         }
@@ -701,7 +698,8 @@ QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString & text)
     return relevantScripts;
 }
 
-QStringList GuessLanguagePrivate::identify(const QString& sample, const QList<QChar::Script>& scripts)
+QStringList GuessLanguagePrivate::identify(const QString &sample,
+                                           const QList<QChar::Script> &scripts)
 {
     if (sample.size() < MIN_LENGTH) {
         return QStringList();
@@ -715,14 +713,15 @@ QStringList GuessLanguagePrivate::identify(const QString& sample, const QList<QC
     return guesses;
 }
 
-QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample, const QStringList &languages)
+QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample,
+                                                    const QStringList &languages)
 {
     QStringList ret;
 
     const QList<QString> sampleTrigrams = createOrderedModel(sample);
 
     // Sort by score
-    QMultiMap<int,QString> scores;
+    QMultiMap<int, QString> scores;
     for (const QString &language : languages) {
         if (s_knownModels.contains(language)) {
             scores.insert(distance(sampleTrigrams, s_knownModels[language]), language);
@@ -737,7 +736,7 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample, const
 
     int counter = 0;
     double confidence = 0;
-    QMapIterator<int,QString> it(scores);
+    QMapIterator<int, QString> it(scores);
     it.next();
 
     QString prevItem = it.value();
@@ -748,8 +747,8 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample, const
         counter++;
         confidence += (it.key() - prevScore)/(double)it.key();
         ret += prevItem;
-        prevItem=it.value();
-        prevScore=it.key();
+        prevItem = it.value();
+        prevScore = it.key();
     }
     if (counter < m_maxItems && confidence < m_minConfidence) {
         ret += prevItem;
@@ -758,40 +757,42 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample, const
     return ret;
 }
 
-
-QList<QString> GuessLanguagePrivate::createOrderedModel(const QString& content)
+QList<QString> GuessLanguagePrivate::createOrderedModel(const QString &content)
 {
-    QHash<QString,int> trigramCounts;
-    QMap<int,QString> orderedTrigrams;
+    QHash<QString, int> trigramCounts;
+    QMap<int, QString> orderedTrigrams;
 
     for (int i = 0; i < (content.size() - 2); ++i) {
         QString tri = content.mid(i, 3).toLower();
         trigramCounts[tri]++;
     }
 
-    foreach (const QString &key, trigramCounts.keys()) {
-        const QChar* data=key.constData();
-        bool hasTwoSpaces=(data[1].isSpace() && (data[0].isSpace() || data[2].isSpace()));
+    for (const QString &key : trigramCounts.keys()) {
+        const QChar *data = key.constData();
+        bool hasTwoSpaces = (data[1].isSpace() && (data[0].isSpace() || data[2].isSpace()));
 
-        if (!hasTwoSpaces) orderedTrigrams.insertMulti( - trigramCounts[key], key);
+        if (!hasTwoSpaces) {
+            orderedTrigrams.insertMulti(-trigramCounts[key], key);
+        }
     }
 
     return orderedTrigrams.values();
 }
 
-int GuessLanguagePrivate::distance(const QList<QString>& model, const QHash<QString,int>& knownModel)
+int GuessLanguagePrivate::distance(const QList<QString> &model, const QHash<QString,
+                                                                            int> &knownModel)
 {
     int counter = -1;
     int dist = 0;
 
-    Q_FOREACH(const QString& trigram, model) {
+    for (const QString &trigram : model) {
         if (knownModel.contains(trigram)) {
             dist += qAbs(++counter - knownModel.value(trigram));
         } else {
             dist += MAXGRAMS;
         }
 
-        if (counter==(MAXGRAMS-1)) {
+        if (counter == (MAXGRAMS-1)) {
             break;
         }
     }
@@ -799,18 +800,20 @@ int GuessLanguagePrivate::distance(const QList<QString>& model, const QHash<QStr
     return dist;
 }
 
-QString GuessLanguagePrivate::guessFromDictionaries(const QString& sentence, const QStringList& candidates)
+QString GuessLanguagePrivate::guessFromDictionaries(const QString &sentence,
+                                                    const QStringList &candidates)
 {
     // Try to see how many languages we can get spell checking for
-    QList<QSharedPointer<SpellerPlugin>> spellers;
-    for (const QString& lang : candidates) {
+    QList<QSharedPointer<SpellerPlugin> > spellers;
+    for (const QString &lang : candidates) {
         if (!Loader::openLoader()->languages().contains(lang)) {
             qCWarning(SONNET_LOG_CORE) << "Dictionary asked for invalid speller" << lang;
             continue;
         }
         QSharedPointer<SpellerPlugin> plugin = Loader::openLoader()->cachedSpeller(lang);
-        if (!plugin.isNull())
+        if (!plugin.isNull()) {
             spellers.append(plugin);
+        }
     }
 
     // If there's no spell checkers, give up
@@ -823,7 +826,9 @@ QString GuessLanguagePrivate::guessFromDictionaries(const QString& sentence, con
     WordTokenizer tokenizer(sentence);
     while (tokenizer.hasNext()) {
         QStringRef word = tokenizer.next();
-        if (!tokenizer.isSpellcheckable()) continue;
+        if (!tokenizer.isSpellcheckable()) {
+            continue;
+        }
 
         for (int i = 0; i < spellers.count(); ++i) {
             if (spellers[i]->isCorrect(word.toString())) {
@@ -832,17 +837,17 @@ QString GuessLanguagePrivate::guessFromDictionaries(const QString& sentence, con
         }
     }
 
-    if (correctHits.isEmpty()) return QString();
+    if (correctHits.isEmpty()) {
+        return QString();
+    }
 
     QMap<QString, int>::const_iterator max = correctHits.constBegin();
     for (QMap<QString, int>::const_iterator itr = correctHits.constBegin();
-        itr != correctHits.constEnd(); ++itr) {
+         itr != correctHits.constEnd(); ++itr) {
         if (itr.value() > max.value()) {
             max = itr;
         }
     }
     return max.key();
 }
-
-
 }
